@@ -12,7 +12,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <gdk/gdk.h>
-#include <gconf/gconf.h>
 #include <math.h>
 #include <time.h>
 #include <errno.h>
@@ -26,7 +25,7 @@
 #include "wp.h"
 
 
-GSList *gconf_get_repolist();
+GSList *settings_get_repolist();
 void repoconfig__set_current_list_pointer();
 void repoconfig__create_dropdown();
 
@@ -34,45 +33,39 @@ void repoconfig__create_dropdown();
 void
 pre_init()
 {
-	GError	**err = NULL;
-
 	g_type_init();
 
 	trackpoint_list = g_queue_new();
 
 	global_home_dir = getenv("HOME");
 
-	global_gconfclient	= gconf_client_get_default();
-	global_curr_reponame	= gconf_client_get_string(global_gconfclient, GCONF"/repo_name",err);
+	global_settings	= g_settings_new(SCHEMA);
+	global_curr_reponame	= g_settings_get_string(global_settings, "repo-name");
 
 
 	if(global_curr_reponame == NULL)
 	{
-		printf("gconf repo_name not set\n");
+		printf("repo_name setting not set\n");
 		global_curr_reponame = g_strdup("OSM");
 	}
-	gconf_get_repolist();	
+	settings_get_repolist();
 	repoconfig__set_current_list_pointer();
-	
-	global_x = gconf_client_get_int(
-				global_gconfclient, 
-				GCONF"/global_x",
-				err);
-	global_y = gconf_client_get_int(
-				global_gconfclient, 
-				GCONF"/global_y",
-				err);
-	global_zoom = gconf_client_get_int(
-				global_gconfclient, 
-				GCONF"/global_zoom",
-				err);
-	global_detail_zoom = gconf_client_get_int (
-				global_gconfclient,
-				GCONF"/global_detail_zoom",
-				err);
+
+	global_x = g_settings_get_int(
+				global_settings,
+				"global-x");
+	global_y = g_settings_get_int(
+				global_settings,
+				"global-y");
+	global_zoom = g_settings_get_int(
+				global_settings,
+				"global-zoom");
+	global_detail_zoom = g_settings_get_int (
+				global_settings,
+				"global-detail-zoom");
 
 
-	if(global_zoom <= 2) 
+	if(global_zoom <= 2)
 	{
 		global_x = 890;
 		global_y = 515;
@@ -80,32 +73,28 @@ pre_init()
 	}
 
 
-	global_server = gconf_client_get_string (global_gconfclient,
-						 GCONF "/gpsd_host",
-						 err);
+	global_server = g_settings_get_string (global_settings,
+						 "gpsd-host");
 	if (global_server == NULL)
 	{
-		printf("gconf GPSD address not set\n");
+		printf("GPSD address setting not set\n");
 		global_server	= g_strdup("127.0.0.1");
 	}
 
-	global_port = gconf_client_get_string (global_gconfclient,
-					       GCONF "/gpsd_port",
-					       err);
+	global_port = g_settings_get_string (global_settings,
+					       "gpsd-port");
 	if (global_port == NULL)
 	{
-		printf("gconf GPSD port not set\n");
+		printf("GPSD port setting not set\n");
 		global_port	= g_strdup("2947");
 	}
 
-	global_no_redownload = gconf_client_get_bool(
-				global_gconfclient,
-				GCONF"/no_redownload",
-				err);
+	global_no_redownload = g_settings_get_boolean(
+				global_settings,
+				"no-redownload");
 
-	global_auto_download = gconf_client_get_bool(global_gconfclient, 
-	                                             GCONF"/auto_download",
-	                                             err);
+	global_auto_download = g_settings_get_boolean(global_settings,
+	                                             "auto-download");
 }
 
 void
@@ -117,25 +106,25 @@ init()
 	gchar buffer[128];
 	gboolean gconf_fftimer_running;
 	char *str = NULL;
-	
-	
+
+
 	foxtrotgps_dir = g_strconcat(global_home_dir, "/." PACKAGE, NULL);
 	g_mkdir(foxtrotgps_dir, 0700);
 
 	repoconfig__create_dropdown();
 
-	
 
 
-	global_gconfclient	= gconf_client_get_default(); 
-	nick			= gconf_client_get_string(global_gconfclient, GCONF"/nick",&err);
-	pass			= gconf_client_get_string(global_gconfclient, GCONF"/pass",&err);
-	me_msg			= gconf_client_get_string(global_gconfclient, GCONF"/me_msg",&err);
-	hrm_bt_addr		= gconf_client_get_string(global_gconfclient, GCONF"/hrm_bt_addr",&err);
-	
-	global_speed_unit	= gconf_client_get_int(global_gconfclient, GCONF"/speed_unit",&err);
-	global_alt_unit		= gconf_client_get_int(global_gconfclient, GCONF"/alt_unit",&err);
-	global_latlon_unit	= gconf_client_get_int(global_gconfclient, GCONF"/latlon_unit",&err);
+
+	global_settings	= g_settings_new(SCHEMA);
+	nick			= g_settings_get_string(global_settings, "nick");
+	pass			= g_settings_get_string(global_settings, "pass");
+	me_msg			= g_settings_get_string(global_settings, "me-msg");
+	hrm_bt_addr		= g_settings_get_string(global_settings, "hrm-bt-addr");
+
+	global_speed_unit	= g_settings_get_int(global_settings, "speed-unit");
+	global_alt_unit		= g_settings_get_int(global_settings, "alt-unit");
+	global_latlon_unit	= g_settings_get_int(global_settings, "latlon-unit");
 
 	widget = lookup_widget(window1, "button3");
 	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(widget),
@@ -156,7 +145,7 @@ init()
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
 			break;
 	}
-	
+
 	switch (global_alt_unit)
 	{
 		case 1:
@@ -164,7 +153,7 @@ init()
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
 			break;
 	}
-	
+
 	switch (global_latlon_unit)
 	{
 		case 1:
@@ -176,7 +165,7 @@ init()
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
 			break;
 	}
-	
+
 	widget  = lookup_widget(window1, "entry7");
 	if(nick)
 		gtk_entry_set_text( GTK_ENTRY(widget), nick );
@@ -190,14 +179,14 @@ init()
 	if(hrm_bt_addr)
 		gtk_entry_set_text( GTK_ENTRY(widget), hrm_bt_addr );
 
-	
+
 	widget = lookup_widget(window1, "vscale1");
 	gtk_range_set_value(GTK_RANGE(widget), (double) global_zoom);
-	
-	global_track_dir	= gconf_client_get_string(global_gconfclient, GCONF"/track_dir",&err);
+
+	global_track_dir	= g_settings_get_string(global_settings, "track-dir");
 	if(!global_track_dir)
 		global_track_dir = g_strdup_printf("%s/Maps/",global_home_dir);
-	
+
 	global_myposition.lat = 0;
 	global_myposition.lon = 0;
 
@@ -208,17 +197,17 @@ init()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
 	                             !global_no_redownload);
 
-	hrm_on = gconf_client_get_bool(global_gconfclient, GCONF"/hrm_on",&err);
+	hrm_on = g_settings_get_boolean(global_settings, "hrm-on");
 	widget = lookup_widget(window1, "checkbutton18");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), hrm_on);
 
 	gconf_fftimer_running = FALSE;
 
-	global_ffupdate_interval_minutes = gconf_client_get_float(global_gconfclient, GCONF"/ffupdate_interval_minutes",&err);
-	
+	global_ffupdate_interval_minutes = g_settings_get_double(global_settings, "ffupdate-interval-minutes");
+
 	if(!global_ffupdate_interval_minutes)
 		global_ffupdate_interval_minutes = 5;
-	
+
 	global_ffupdate_interval = global_ffupdate_interval_minutes * 60000;
 
 	if (global_ffupdate_interval_minutes<5)
@@ -227,31 +216,29 @@ init()
 		g_sprintf(buffer, "%.0f", global_ffupdate_interval_minutes);
 
 	widget = lookup_widget(window1, "entry16");
-	gtk_entry_set_text( GTK_ENTRY(widget), buffer );
-	
+	// gtk_entry_set_text( GTK_ENTRY(widget), buffer );
 
-	
 	if(gconf_fftimer_running)
 	{
 		widget = lookup_widget(menu1, "item19");
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), TRUE);
 	}
-		
-	
 
-	str = gconf_client_get_string(global_gconfclient, GCONF"/gpsd_host",&err);
+
+
+	str = g_settings_get_string(global_settings, "gpsd-host");
 	widget = lookup_widget(window1, "entry3");
 	if(str)
 		gtk_entry_set_text(GTK_ENTRY(widget), g_strdup(str));
 	g_free(str);
-	
-	str = gconf_client_get_string(global_gconfclient, GCONF"/gpsd_port",&err);
+
+	str = g_settings_get_string(global_settings, "gpsd-port");
 	widget = lookup_widget(window1, "entry4");
 	if(str)
 		gtk_entry_set_text(GTK_ENTRY(widget), g_strdup(str));
 	g_free(str);
-	
-	if (gconf_client_get_bool(global_gconfclient, GCONF"/tracklog_on", NULL)) {
+
+	if (g_settings_get_boolean(global_settings, "tracklog-on")) {
 		widget = lookup_widget(window1, "checkbutton17");
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
 	}
@@ -265,28 +252,23 @@ init()
 		         err->message);
 		g_error_free (err);
 	}
-	
-	
-	global_myposition.lat = gconf_client_get_float(global_gconfclient, GCONF"/myposition_lat", NULL);
-	global_myposition.lon = gconf_client_get_float(global_gconfclient, GCONF"/myposition_lon", NULL);
+
+
+	global_myposition.lat = g_settings_get_double(global_settings, "myposition-lat");
+	global_myposition.lon = g_settings_get_double(global_settings, "myposition-lon");
 	paint_myposition();
 }
 
 GSList *
-gconf_get_repolist()
+settings_get_repolist()
 {
-	GSList	*repo_list;
-	
-	GSList	*list;
-	GError **error = NULL;
-	
-	
-	repo_list = gconf_client_get_list(	global_gconfclient, 
-						GCONF"/repos",
-						GCONF_VALUE_STRING,
-						error);
-	
-	if (repo_list == NULL)
+	gchar  **repo_list;
+
+
+	repo_list = g_settings_get_strv(	global_settings,
+						"repos");
+
+	if (repo_list == NULL || repo_list[0] == NULL)
 	{
 		repo_t *repo1 = g_new0(repo_t, 1);
 		repo_t *repo2 = g_new0(repo_t, 1);
@@ -294,11 +276,11 @@ gconf_get_repolist()
 		repo_t *repo4 = g_new0(repo_t, 1);
 		repo_t *repo5 = g_new0(repo_t, 1);
 
-		
+
 		printf("REPOLIST == NULL\n");
-		
+
 		repo1->name = g_strdup("OSM");
-		repo1->uri  = g_strdup("http://tile.openstreetmap.org/%d/%d/%d.png");
+		repo1->uri  = g_strdup("https://tile.openstreetmap.org/%d/%d/%d.png");
 		repo1->dir  = g_strdup_printf("%s/Maps/OSM",global_home_dir);
 		repo1->inverted_zoom = 0;
 		global_repo_list = g_slist_append(global_repo_list, repo1);
@@ -308,7 +290,7 @@ gconf_get_repolist()
 		repo2->dir  = g_strdup_printf("%s/Maps/maps4free",global_home_dir);
 		repo2->inverted_zoom = 0;
 		global_repo_list = g_slist_append(global_repo_list, repo2);
-				
+
 		repo3->name = g_strdup("OpenCycleMap");
 		repo3->uri  = g_strdup("http://tile.opencyclemap.org/cycle/%d/%d/%d.png");
 		repo3->dir  = g_strdup_printf("%s/Maps/opencyclemap",global_home_dir);
@@ -316,82 +298,79 @@ gconf_get_repolist()
 		global_repo_list = g_slist_append(global_repo_list, repo3);
 
 		repo4->name = g_strdup("Google Maps (testing only)");
-		repo4->uri  = g_strdup("http://mt0.google.com/vt/lyrs=m&hl=en&x=%d&y=%d&z=%d");
+		repo4->uri  = g_strdup("https://mt0.google.com/vt/lyrs=m&hl=en&x=%d&y=%d&z=%d");
 		repo4->dir  = g_strdup_printf("%s/Maps/googlemaps",global_home_dir);
 		repo4->inverted_zoom = 1;
 		global_repo_list = g_slist_append(global_repo_list, repo4);
 
 		repo5->name = g_strdup("Google Sat (testing only)");
-		repo5->uri  = g_strdup("http://mt0.google.com/vt/lyrs=s&hl=en&x=%d&y=%d&z=%d");
+		repo5->uri  = g_strdup("https://mt0.google.com/vt/lyrs=s&hl=en&x=%d&y=%d&z=%d");
 		repo5->dir  = g_strdup_printf("%s/Maps/googlesat",global_home_dir);
 		repo5->inverted_zoom = 1;
 		global_repo_list = g_slist_append(global_repo_list, repo5);
 
 
 	}
-	
-	
-	for(list = repo_list; list != NULL; list = list->next)
+
+
+	for(gint i = 0; repo_list[i] != NULL; i++)
 	{
 		gchar **array;
-		gchar *str = list->data;
+		gchar *str = repo_list[i];
 		repo_t *repo = g_new0(repo_t, 1);
-		
-		array = g_strsplit(str,"|",4);	
-		
+
+		array = g_strsplit(str,"|",4);
+
 		repo->name = g_strdup(array[0]);
 		repo->uri  = g_strdup(array[1]);
 		repo->dir  = g_strdup(array[2]);
 		repo->inverted_zoom = (atoi(g_strdup(array[3])) == 1) ? TRUE : FALSE;
-		
-		global_repo_list = g_slist_append(global_repo_list, repo);
 
-		printf("GCONF: \n -- name: %s \n -- uri: %s \n -- dir: %s \n",
-			repo->name, repo->uri, repo->dir);
+		global_repo_list = g_slist_append(global_repo_list, repo);
 	}
-	
-	
-	return global_repo_list;	
-					
+
+
+	g_strfreev (repo_list);
+
+	return global_repo_list;
+
 }
 
 void
-gconf_set_repolist()
+settings_set_repolist()
 {
-	
-	GSList	*list;
-	GSList	*gconf_list = NULL;
-	GError **error = NULL;
+
+	GSList	  *list;
+	GPtrArray *setting_list = NULL;
 	gboolean success = FALSE;
-	
-	
-	
+
+
+
+	setting_list = g_ptr_array_new ();
+
 	for(list = global_repo_list; list != NULL; list = list->next)
 	{
 		repo_t *repo;
-		gchar gconf_str[1024];
-		
+		gchar setting_str[1024];
+
 		repo = list->data;
-		
-		
-		g_sprintf(	gconf_str, 
+
+
+		g_sprintf(	setting_str,
 				"%s|%s|%s|%i",
 				repo->name, repo->uri, repo->dir, repo->inverted_zoom);
-		
-		gconf_list = g_slist_append(gconf_list, g_strdup(gconf_str));
 
-		printf("GCONFSAVE: \n -- name: %s \n -- uri: %s \n -- dir: %s \n -- zoom: %i \n\n %s \n",
-			repo->name, repo->uri, repo->dir, repo->inverted_zoom, gconf_str);
+	        g_ptr_array_add(setting_list, (gpointer) g_strdup(setting_str));
 	}
-	
-	success = gconf_client_set_list(	global_gconfclient, 
-						GCONF"/repos",
-						GCONF_VALUE_STRING,
-						gconf_list,
-						error);
-	
-	printf("*** %s(): %i \n",__PRETTY_FUNCTION__, success);
 
+	g_ptr_array_add(setting_list, NULL);
+
+	success = g_settings_set_strv(	global_settings,
+						"repos",
+						(const gchar * const *) setting_list->pdata);
+
+	g_strfreev((gchar **) setting_list->pdata);
+	g_ptr_array_free (setting_list, FALSE);
 }
 
 
@@ -399,33 +378,33 @@ gconf_set_repolist()
 void
 repoconfig__set_current_list_pointer()
 {
-	
-	
+
+
 	GSList		*list;
 	const gchar	*reponame;
 	int unused;
-	
+
 	for(list = global_repo_list; list != NULL; list = list->next)
 	{
 		repo_t *repo;
 		repo	= list->data;
-		
+
 		reponame = g_strdup(repo->name);
-		
+
 		if(	g_strrstr(reponame,global_curr_reponame) != NULL &&
-			strlen(reponame) == strlen(global_curr_reponame)	
+			strlen(reponame) == strlen(global_curr_reponame)
 		)
 			global_curr_repo = list;
 	}
 	if(!global_curr_repo)
 	{
 		printf("\n#\n#\n#  ERROR: repository %s is broken \n#\n#\n", global_curr_reponame);
-		
+
 		printf("Resetting repo_name and exiting now.\n\n");
 		printf("If problem persists after restart, \n");
-		printf("execute in a terminal: gconftool-2 -u " GCONF "/repos\n");
-		unused = system("gconftool-2 -u " GCONF "/repo_name");
-		exit(EXIT_FAILURE);		
+		printf("execute in a terminal: gsettings reset " SCHEMA " repos\n");
+		unused = system("gsettings reset " SCHEMA " repo_name");
+		exit(EXIT_FAILURE);
 	}
 }
 
@@ -438,19 +417,19 @@ repoconfig__create_dropdown()
 	int 		i = 0;
 	int		j = 0;
 	const gchar	*reponame;
-	
+
 	combobox = lookup_widget(window1, "combobox1");
 
 	for(list = global_repo_list; list != NULL; list = list->next)
 	{
 		repo_t	*repo;
-		
+
 		repo = list->data;
 		reponame = g_strdup(repo->name);
 		gtk_combo_box_append_text (GTK_COMBO_BOX(combobox), g_strdup(repo->name));
-		
+
 		if(	g_strrstr(reponame,global_curr_reponame) != NULL &&
-			strlen(reponame) == strlen(global_curr_reponame)	
+			strlen(reponame) == strlen(global_curr_reponame)
 		)
 		{
 			j = i;
