@@ -5,4 +5,4 @@ void
 pre_init();
 
 void
-gconf_set_repolist();
+settings_set_repolist();
