@@ -2,7 +2,6 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf.h>
 #include <math.h>
 #include "support.h"
 #include "globals.h"
@@ -52,9 +51,9 @@ gboolean
 hash_sieve_func (gpointer key, gpointer value, gpointer user_data)
 {
 	gboolean remove = TRUE;
-	
+
 	tile_hash_t *tile_hash = value;
-	
+
 	if(tile_hash->reused)
 	{
 		tile_hash->reused = FALSE;
@@ -85,7 +84,7 @@ load_tile(	gchar *dir,
 	repo_t 		*repo;
 	tile_hash_t	*tile_hash;
 
-	
+
 	if(gc_map)
 		g_object_unref(gc_map);
 	if(pixmap)
@@ -99,35 +98,35 @@ load_tile(	gchar *dir,
 
 	g_snprintf(wanted_filename, 255, "%s/%u/%u/%u.png", dir, zoom, x, y);
 	tile_hash = g_hash_table_lookup(hash_table, wanted_filename);
-	
+
 	if(tile_hash)
 	{
 		pixbuf = tile_hash->pixbuf;
-		
+
 		tile_hash->reused = TRUE;
 		hash_not_found	  = FALSE;
 	}
-	
+
 	else
 	{
-		
+
 		for(overzoom=0; overzoom<=3; overzoom++)
 		{
 			g_snprintf(filename, 255, "%s/%u/%u/%u.png", dir, zoom-overzoom, x/upscale, y/upscale);
-	
+
 			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-	
+
 			if(pixbuf)
 				break;
-	
+
 			upscale *= 2;
 		}
-		
+
 		if(pixbuf && upscale > 1)
 		{
 			GdkPixbuf	*pixbuf_scaled	= NULL;
-			pixbuf_scaled = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, 256, 256); 
-	
+			pixbuf_scaled = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, 256, 256);
+
 			gdk_pixbuf_scale (	pixbuf, pixbuf_scaled,
 						0, 0,
 						TILESIZE, TILESIZE,
@@ -142,14 +141,14 @@ load_tile(	gchar *dir,
 			pixbuf = pixbuf_scaled;
 		}
 	}
-	
+
 	if(!pixbuf)
 	{
-		
+
 		GtkWidget *widget;
-			
+
 		widget = lookup_widget(window1, "drawingarea1");
-			
+
 		gdk_draw_rectangle (
 			pixmap,
 			widget->style->white_gc,
@@ -157,15 +156,15 @@ load_tile(	gchar *dir,
 			offset_x, offset_y,
 			256,
 			256);
-						
+
 		gtk_widget_queue_draw_area (
 			widget,
 			offset_x,offset_y,256,256);
 	}
-	
+
 	else
 	{
-		
+
 		gdk_draw_pixbuf (
 			pixmap,
 			gc_map,
@@ -175,22 +174,22 @@ load_tile(	gchar *dir,
 			TILESIZE,TILESIZE,
 			GDK_RGB_DITHER_NONE, 0, 0);
 
-		
+
 		if(hash_not_found)
 		{
 			tile_hash = g_new0(tile_hash_t,1);
 			tile_hash->pixbuf = pixbuf;
 			tile_hash->reused = TRUE;
-	
+
 			g_hash_table_insert(hash_table, g_strdup(wanted_filename), tile_hash);
 		}
 	}
 
-	
+
 	drawingarea11 = lookup_widget(window1, "drawingarea1");
-	
+
 	gtk_widget_queue_draw_area (
-		drawingarea11, 
+		drawingarea11,
 		offset_x,offset_y,
 		TILESIZE,TILESIZE);
 
@@ -198,7 +197,7 @@ load_tile(	gchar *dir,
 	{
 		repo = global_curr_repo->data;
 		download_tile(repo,zoom,x/detail_scale,y/detail_scale);
-	}	
+	}
 }
 
 
@@ -217,10 +216,9 @@ fill_tiles_pixel(	int pixel_x,
 	int offset_x;
 	int offset_y;
 	gboolean success = FALSE;
-	GError **error = NULL;
 	repo_t *repo = global_curr_repo->data;
-	
-	
+
+
 	if (!hash_table)
 	{
 		hash_table = g_hash_table_new_full (g_str_hash,
@@ -228,35 +226,35 @@ fill_tiles_pixel(	int pixel_x,
 						    hash_destroy_key_func,
 						    hash_destroy_value_func);
 	}
-	
+
 	if(force_refresh)
 	{
-		g_hash_table_remove_all(hash_table);	
+		g_hash_table_remove_all(hash_table);
 	}
-	
-	widget = lookup_widget(window1,"drawingarea1");
-	
 
-	
-	max_pixel = (int) exp2(zoom) * TILESIZE; 
+	widget = lookup_widget(window1,"drawingarea1");
+
+
+
+	max_pixel = (int) exp2(zoom) * TILESIZE;
 
 	if(pixel_x < 0)
 		pixel_x += max_pixel;
-	
-	else if (pixel_x > max_pixel)
-		pixel_x -= max_pixel;	
 
-	
+	else if (pixel_x > max_pixel)
+		pixel_x -= max_pixel;
+
+
 	offset_x = - pixel_x % TILESIZE;
 	offset_y = - pixel_y % TILESIZE;
 	if (offset_x > 0) offset_x -= 256;
 	if (offset_y > 0) offset_y -= 256;
-	
+
 	global_x = pixel_x;
 	global_y = pixel_y;
 	global_zoom = zoom;
-	
-	offset_xn = offset_x; 
+
+	offset_xn = offset_x;
 	offset_yn = offset_y;
 
 	width  = map_drawable->allocation.width;
@@ -264,20 +262,20 @@ fill_tiles_pixel(	int pixel_x,
 
 	tiles_nx = floor((width  - offset_x) / TILESIZE) + 1;
 	tiles_ny = floor((height - offset_y) / TILESIZE) + 1;
-	
+
 	tile_x0 =  floor((float)pixel_x / (float)TILESIZE);
 	tile_y0 =  floor((float)pixel_y / (float)TILESIZE);
-	
-	
+
+
 
 	for (i=tile_x0; i<(tile_x0+tiles_nx); i++)
 	{
 		for (j=tile_y0;  j<(tile_y0+tiles_ny); j++)
 		{
-			
-			
 
-			
+
+
+
 			if(j<0 || j>=exp2(zoom))
 			{
 				gdk_draw_rectangle (
@@ -287,16 +285,16 @@ fill_tiles_pixel(	int pixel_x,
 					offset_xn, offset_yn,
 					TILESIZE,
 					TILESIZE);
-				
+
 				gtk_widget_queue_draw_area (
-					widget, 
+					widget,
 					offset_xn,offset_yn,
 					TILESIZE,TILESIZE);
 			}
 			else
-			{	
+			{
 				i_corrected = (i>=exp2(zoom)) ? i-exp2(zoom) : i;
-				
+
 				load_tile(
 					repo->dir,
 					zoom,
@@ -309,25 +307,22 @@ fill_tiles_pixel(	int pixel_x,
 		offset_yn = offset_y;
 	}
 
-	
+
 	g_hash_table_foreach_remove (hash_table, hash_sieve_func, NULL);
-	
-	
-	success = gconf_client_set_int(
-				global_gconfclient, 
-				GCONF"/global_x",
-				global_x,
-				error);
-	success = gconf_client_set_int(
-				global_gconfclient, 
-				GCONF"/global_y",
-				global_y,
-				error);
-	success = gconf_client_set_int(
-				global_gconfclient, 
-				GCONF"/global_zoom",
-				global_zoom,
-				error);
+
+
+	success = g_settings_set_int(
+				global_settings,
+				"global-x",
+				global_x);
+	success = g_settings_set_int(
+				global_settings,
+				"global-y",
+				global_y);
+	success = g_settings_set_int(
+				global_settings,
+				"global-zoom",
+				global_zoom);
 }
 
 void
@@ -336,15 +331,12 @@ fill_tiles_latlon(	float lat,
 			int zoom)
 {
 	int pixel_x, pixel_y;
-	
-	
+
+
 	pixel_x = lon2pixel(zoom, lon);
 
 	pixel_y = lat2pixel(zoom, lat);
 
-	printf("fill_tiles_latlon(): lat %f  %i -- lon %f  %i\n",
-	lat,pixel_y,lon,pixel_x);
-	
 	fill_tiles_pixel (pixel_x, pixel_y, zoom, FALSE);
 }
 
@@ -354,17 +346,17 @@ set_mapcenter(	float lat,
 		int zoom)
 {
 	int pixel_x, pixel_y;
-	
+
 	lat = deg2rad(lat);
 	lon = deg2rad(lon);
-	
-	
+
+
 	pixel_x = lon2pixel(zoom, lon);
 	pixel_y = lat2pixel(zoom, lat);
 
-	
+
 	osd_speed(TRUE);
-	fill_tiles_pixel (	pixel_x - global_drawingarea_width/2, 
+	fill_tiles_pixel (	pixel_x - global_drawingarea_width/2,
 				pixel_y - global_drawingarea_height/2,
 				zoom, FALSE);
 	paint_track();
