@@ -57,22 +57,22 @@ double
 parse_degrees(const char *s)
 {
 	float deg, min, sec;
-	
-	
+
+
 	if (3 == sscanf(s, "%f %f %f", &deg, &min, &sec))
 		return deg + min/60 + sec/3600;
 	else if (3 == sscanf(s, "%f° %f' %f\"", &deg, &min, &sec))
 		return deg + min/60 + sec/3600;
 	else if (3 == sscanf(s, "%f°%f'%f\"", &deg, &min, &sec))
 		return deg + min/60 + sec/3600;
-		
+
 	else if (2 == sscanf(s, "%f %f", &deg, &min))
 		return deg + min/60;
- 	else if (2 == sscanf(s, "%f° %f'", &deg, &min))
+	else if (2 == sscanf(s, "%f° %f'", &deg, &min))
 		return deg + min/60;
 	else if (2 == sscanf(s, "%f°%f'", &deg, &min))
 		return deg + min/60;
-		
+
 	else if (1 == sscanf(s, "%f", &deg))
 		return deg;
 
@@ -85,8 +85,6 @@ sql_cb__poi_get(void *unused, int colc, char **colv, char **col_names)
 {
 	poi_t *poi = g_new0(poi_t,1);
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-	
 	poi->idmd5		= g_strdup(colv[0]);
 	poi->lat_deg		= atof(colv[1]);
 	poi->lon_deg		= atof(colv[2]);
@@ -97,7 +95,7 @@ sql_cb__poi_get(void *unused, int colc, char **colv, char **col_names)
 	poi->desc		= g_strdup(colv[7]);
 	poi->price_range	= atoi(colv[8]);
 	poi->extended_open	= atoi(colv[9]);
-	
+
 	poi_list = g_slist_prepend(poi_list, poi);
 
 	return 0;
@@ -132,7 +130,7 @@ get_poi_icon (poi_t *poi)
 			g_build_filename (foxtrotgps_dir, "poi-icons", NULL);
 
 		/* Not all characters that might be in a POI's name
-		   are suitable for use in icon-filenames, e.g.: 
+		   are suitable for use in icon-filenames, e.g.:
 		   path-separators need to be escaped so that
 		   a POI named something like "../../evil"
 		   doesn't result in us reading/writing a file
@@ -154,7 +152,7 @@ get_poi_icon (poi_t *poi)
 		if (!g_file_test (icon_path, G_FILE_TEST_EXISTS)) {
 			pid_t mkvisualid_pid;
 			int mkvisualid_status;
-	
+
 			char *autocache_dir =
 				g_build_filename (global_home_dir,
 				                  ".VisualIDs",
@@ -164,9 +162,9 @@ get_poi_icon (poi_t *poi)
 			g_mkdir_with_parents (autocache_dir, 0777);
 			/* Free autocache_dir later--we need to pass it
 			   to mkvisualid, below... */
-	
+
 			mkvisualid_pid = fork();
-	
+
 			switch (mkvisualid_pid) {
 			case 0:
 				execlp ("mkvisualid", "mkvisualid",
@@ -193,7 +191,7 @@ get_poi_icon (poi_t *poi)
 				g_free (autocache_dir);
 			}
 		}
-	
+
 		icon = gdk_pixbuf_new_from_file_at_size
 			(icon_path, 32, 32, NULL);
 		/*^Note that this is slightly bigger than
@@ -224,27 +222,27 @@ get_poi_icon (poi_t *poi)
 void
 paint_pois()
 {
-	
-	
+
+
 	int pixel_x, pixel_y, x, y;
 	float lat, lon;
 	GSList *list;
 	GdkColor color;
 	static GdkGC *gc;
-	
+
 
 	if (!gc)
-		gc = gdk_gc_new(pixmap); 
+		gc = gdk_gc_new(pixmap);
 	color.green = 0;
 	color.blue = 60000;
 	color.red = 0;
 	gdk_gc_set_rgb_fg_color(gc, &color);
-	
+
 
 	if(global_show_pois)
 	{
 		get_pois();
-		
+
 		for(list = poi_list; list != NULL; list = list->next)
 		{
 			poi_t *p = list->data;
@@ -252,33 +250,33 @@ paint_pois()
 			GdkPixbuf *photo_icon = get_poi_icon (p);
 			int icon_width = gdk_pixbuf_get_width (photo_icon);
 			int icon_height = gdk_pixbuf_get_width (photo_icon);
-		
+
 			lat = deg2rad(p->lat_deg);
 			lon = deg2rad(p->lon_deg);
-			
-			
-			
+
+
+
 			pixel_x = lon2pixel(global_zoom, lon);
 			pixel_y = lat2pixel(global_zoom, lat);
-			
+
 			x = pixel_x - global_x;
 			y = pixel_y - global_y;
-			
+
 			p->screen_x = x;
 			p->screen_y = y;
-			
-			
-			
+
+
+
 			if(!photo_icon)
 			{
 				gdk_draw_arc (
 					pixmap,
-					
+
 					gc,
-					TRUE,			
-					x-4, y-4,		
-					8,8,			
-					0,23040);		
+					TRUE,
+					x-4, y-4,
+					8,8,
+					0,23040);
 			}
 			else
 			{
@@ -290,15 +288,13 @@ paint_pois()
 					x - icon_width/2, y - icon_height/2,
 					-1, -1,
 					GDK_RGB_DITHER_NONE, 0, 0);
-				
+
 			}
-			
+
 			gtk_widget_queue_draw_area (
-					map_drawable, 
+					map_drawable,
 					x - icon_width/2, y - icon_height/2,
 					icon_width, icon_height);
-			
-			printf("POI: %s lat %f - lon %f\n",p->keywords,p->lat_deg, p->lon_deg);
 		}
 	}
 }
@@ -313,66 +309,62 @@ create_combobox_list_store(char *list)
 	GtkTreeIter	iter;
 	int		i=0;
 	char		**array;
-	
+
 	list_store = gtk_list_store_new (N_COLUMNS,
-				   G_TYPE_STRING,
-				   G_TYPE_INT,
-				   G_TYPE_BOOLEAN);
+	                                 G_TYPE_STRING,
+	                                 G_TYPE_INT,
+	                                 G_TYPE_BOOLEAN);
 
 	array = g_strsplit(list,"|",-1);
-	
+
 	while(array[i])
-	{		
-		
-		
+	{
+
+
 		gtk_list_store_append (list_store, &iter);
 		gtk_list_store_set (list_store, &iter,
-				  COLUMN_STRING, array[i],
-				  COLUMN_INT, i,
-				  COLUMN_BOOLEAN,  FALSE,
-				  -1);
-		
+		                    COLUMN_STRING, array[i],
+		                    COLUMN_INT, i,
+		                    COLUMN_BOOLEAN,  FALSE,
+		                    -1);
+
 		i++;
 	}
-	
+
 	g_strfreev(array);
 	return list_store;
-}	
+}
 
 
 
 void
-on_combobox_subcat_changed                   (GtkComboBox     *combobox,
-                                        gpointer         user_data)
+on_combobox_subcat_changed(GtkComboBox     *combobox,
+                           gpointer         user_data)
 {
-	
-	
-	
+
+
+
 	GtkTreeIter iter;
 	gchar *str_data;
 	gint   int_data;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-	
+
 	gtk_combo_box_get_active_iter(combobox, &iter);
-	
-	gtk_tree_model_get (GTK_TREE_MODEL(list_store), &iter, 
-                          COLUMN_STRING, &str_data,
-                          COLUMN_INT, &int_data,
-                          -1);
-	printf("Entry: (%s,%d)\n", str_data, int_data);
+
+	gtk_tree_model_get (GTK_TREE_MODEL(list_store), &iter,
+	                    COLUMN_STRING, &str_data,
+	                    COLUMN_INT, &int_data,
+	                    -1);
 }
 
 
 void set_combobox_subcat(GtkWidget *widget, int choice)
 {
-	
+
 	GtkCellRenderer *renderer;
 	GtkWidget *vbox;
 	char *subcat_lists[16];
-		printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-	subcat_lists[0] = "---"; 
+	subcat_lists[0] = "---";
 	subcat_lists[1] = _("- Please choose -|Hotel|Motel|B&B|Hostel|Camping");
 	subcat_lists[2] = _("- Please choose -|Bank / Exchange / ATM|Post Office|Real Estate Agency|Travel Agency|Other");
 	subcat_lists[3] = _("- Please choose -|Parking|Gas Station|Repair Shop|Rental|Sharing|Dealer|Radar - Speed Trap|My Car");
@@ -389,14 +381,14 @@ void set_combobox_subcat(GtkWidget *widget, int choice)
 	subcat_lists[14] = _("- Please choose -|Friend|Other Cool Place");
 	subcat_lists[15] = _("- Please choose -|Traditional|Multi|Virtual|Letterbox Hybrid|Event|Unknown|Project Ape|Webcam|Cache In Trash Out|Earthcache|Mega-Event|GPS Adventures|Wherigo|Other");
 	/*
-         * NOTE: for geocaching, should also be:
-         * subsubcat[] = "- Please choose -|Micro|Small|Regular|Large|Virtual|Unknown|Other|";
-         */
+	 * NOTE: for geocaching, should also be:
+	 * subsubcat[] = "- Please choose -|Micro|Small|Regular|Large|Virtual|Unknown|Other|";
+	 */
 
 	vbox = lookup_widget(widget, "vbox28");
 	list_store = create_combobox_list_store(subcat_lists[choice]);
-	
-	
+
+
 	if((!combobox_subcat || new_dialog ) && choice)
 	{
 		combobox_subcat = gtk_combo_box_new_with_model (GTK_TREE_MODEL(list_store));
@@ -409,7 +401,6 @@ void set_combobox_subcat(GtkWidget *widget, int choice)
 					G_CALLBACK (on_combobox_subcat_changed),
 					NULL);
 		gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_subcat), 0);
-		printf("reorder\n");
 		gtk_box_reorder_child(GTK_BOX(vbox),combobox_subcat,6);
 		new_dialog = FALSE;
 	}
@@ -418,7 +409,7 @@ void set_combobox_subcat(GtkWidget *widget, int choice)
 		gtk_combo_box_set_model(GTK_COMBO_BOX(combobox_subcat), GTK_TREE_MODEL(list_store));
 		gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_subcat), 0);
 	}
-	
+
 
 }
 
@@ -427,14 +418,12 @@ void
 on_combobox_cat_changed(GtkComboBox     *combobox)
 {
 	int choice;
-		printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-	
 	choice = gtk_combo_box_get_active(combobox);
-	
-	
+
+
 	set_combobox_subcat(GTK_WIDGET(combobox),choice);
-	
+
 }
 
 
@@ -448,8 +437,6 @@ show_window6()
 	double lat, lon, lat_deg, lon_deg;
 	char buf[64];
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-
 	gladexml = glade_xml_new (gladefile, "window6", GETTEXT_PACKAGE);
 	glade_xml_signal_autoconnect (gladexml);
 	dialog = glade_xml_get_widget (gladexml, "window6");
@@ -457,21 +444,21 @@ show_window6()
 				  G_CALLBACK (g_object_unref), gladexml);
 	gtk_widget_show(dialog);
 	new_dialog = TRUE;
-	
-	
+
+
 	lat = pixel2lat(global_zoom, global_y+mouse_y);
 	lon = pixel2lon(global_zoom, global_x+mouse_x);
 	lat_deg = rad2deg(lat);
 	lon_deg = rad2deg(lon);
 	entry14 = lookup_widget(dialog, "entry14");
 	entry15 = lookup_widget(dialog, "entry15");
-	
+
 	g_sprintf(buf, "%f", lat_deg);
 	gtk_entry_set_text(GTK_ENTRY(entry14), buf);
 	g_sprintf(buf, "%f", lon_deg);
 	gtk_entry_set_text(GTK_ENTRY(entry15), buf);
-	
-	
+
+
 	combobox2 = lookup_widget(dialog, "combobox2");
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox2), 0);
 
@@ -498,16 +485,14 @@ set_poi(GtkWidget *dialog)
 	int res;
 	double rand1, rand2;
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-
 	entry = lookup_widget(dialog, "entry14");
-	
+
 	lat_deg = parse_degrees(gtk_entry_get_text(GTK_ENTRY(entry)));
 	entry = lookup_widget(dialog, "entry15");
-	
+
 	lon_deg = parse_degrees(gtk_entry_get_text(GTK_ENTRY(entry)));
 	radiobutton = lookup_widget(dialog, "radiobutton11");
-	visibility = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton))) ? 1 : 0;	
+	visibility = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton))) ? 1 : 0;
 	combo_box = GTK_COMBO_BOX(lookup_widget(dialog, "combobox2"));
 	category = gtk_combo_box_get_active(combo_box);
 	subcategory = gtk_combo_box_get_active(GTK_COMBO_BOX(combobox_subcat));
@@ -527,25 +512,22 @@ set_poi(GtkWidget *dialog)
 	radiobutton = lookup_widget(dialog, "checkbutton10");
 	extended_open = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton))) ? 1 : 0;
 
-	
+
 	rand1 = g_random_double_range (100000000,1000000000);
 	rand2 = g_random_double_range (100000000,1000000000);
 
-	
-	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);	
-	
-	sql = sqlite3_mprintf ( 	
+
+	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);
+
+	sql = sqlite3_mprintf (
 			"INSERT INTO poi "
 			"(idmd5, lat, lon, visibility, cat, subcat, keywords, desc, price_range, extended_open) "
 			"VALUES ('%.0f%.0f',%f,%f,%d,%d,%d,%Q,%Q,%d,%d)",
-			rand1, rand2, lat_deg, lon_deg, visibility, category, subcategory, 
+			rand1, rand2, lat_deg, lon_deg, visibility, category, subcategory,
 			keyword, desc, price_range, extended_open);
-		  
-printf("SQL: %s\n",sql);
-printf("size of gdouble: %d", (int)sizeof(double));
 
 	res = sql_execute(db, sql, NULL);
-	
+
 	if(res==1)
 	{
 		sql_execute(db, POI_DB_CREATE, NULL);
@@ -555,8 +537,8 @@ printf("size of gdouble: %d", (int)sizeof(double));
 	g_free(desc);
 	sqlite3_free (sql);
 	gtk_widget_destroy(dialog);
-	
-	
+
+
 	global_poi_cat = category;
 }
 
@@ -568,7 +550,7 @@ update_poi(GtkWidget *dialog)
 	GtkTextView *text_view;
 	GtkTextBuffer *buffer;
 	GtkTextIter start, end;
-	GtkWidget *entry, *widget; 
+	GtkWidget *entry, *widget;
 
 	const char *keyword, *idmd5;
 	char *desc;
@@ -578,24 +560,21 @@ update_poi(GtkWidget *dialog)
 
 	double lat_deg, lon_deg;
 	int res;
-	
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-	
 	widget = lookup_widget(dialog, "label126");
 	idmd5 = gtk_label_get_text(GTK_LABEL(widget));
-	
+
 	entry = lookup_widget(dialog, "entry17");
-	
+
 	lat_deg = parse_degrees(gtk_entry_get_text(GTK_ENTRY(entry)));
 	entry = lookup_widget(dialog, "entry18");
-	
+
 	lon_deg = parse_degrees(gtk_entry_get_text(GTK_ENTRY(entry)));
 
 
 
-	
+
 
 
 
@@ -608,11 +587,11 @@ update_poi(GtkWidget *dialog)
 	desc = gtk_text_buffer_get_text(buffer, &start, &end, TRUE);
 
 
-	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);	
-	
+	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);
 
 
-	sql = sqlite3_mprintf ( 	
+
+	sql = sqlite3_mprintf (
 			"UPDATE "
 				"poi "
 			"SET "
@@ -621,16 +600,13 @@ update_poi(GtkWidget *dialog)
 				"keywords=%Q,"
 				"desc=%Q"
 			"WHERE "
-				"idmd5='%s'" 
+				"idmd5='%s'"
 			,
-			lat_deg, lon_deg, 
+			lat_deg, lon_deg,
 			keyword, desc, idmd5);
 
-
-printf("SQL: %s\n",sql);
-
 	res = sql_execute(db, sql, NULL);
-	
+
 	if(res==1)
 	{
 		sql_execute(db, POI_DB_CREATE, NULL);
@@ -639,10 +615,10 @@ printf("SQL: %s\n",sql);
 
 	g_free(desc);
 	sqlite3_free (sql);
-	
+
 	gtk_widget_destroy(dialog);
-	
-	
+
+
 
 }
 
@@ -657,28 +633,22 @@ delete_poi(poi_t *p)
 	char *sql;
 	int res;
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
+	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);
 
-	
-
-	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);	
-	
-	sql = g_strdup_printf( 	
+	sql = g_strdup_printf(
 			"DELETE FROM "
 				"poi "
 			"WHERE "
-				"idmd5='%s'" 
+				"idmd5='%s'"
 			, p->idmd5);
 
-printf("SQL: %s\n",sql);
-
 	res = sql_execute(db, sql, NULL);
-	
+
 
 	repaint_all();
 
-	
-	
+
+
 }
 
 
@@ -691,57 +661,54 @@ get_pois()
 	char sql[256];
 	char *db;
 	bbox_t bbox;
-		
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	bbox = get_bbox_deg();
 
 	db = g_strconcat(foxtrotgps_dir, "/", POI_DB, NULL);
 
-	
+
 	if(poi_list) g_slist_free(poi_list);
 	poi_list = NULL;
-	
-	
-	
+
+
+
 	if(global_poi_cat==0)
 	{
-		g_snprintf(sql, 256, 
+		g_snprintf(sql, 256,
 				"SELECT * FROM poi "
 				"WHERE lat<%f AND lat>%f AND lon>%f AND lon<%f "
 				"LIMIT 1000;",
 				bbox.lat1,bbox.lat2,
 				bbox.lon1, bbox.lon2
 				);
-		printf("%s \n",sql);
 	}
 	else if(global_poi_cat>=1)
 	{
 
-		g_snprintf(sql, 256, 
+		g_snprintf(sql, 256,
 				"SELECT * FROM poi "
 				"WHERE  cat=%d AND lat<%f AND lat>%f AND lon>%f AND lon<%f "
 				"LIMIT 1000;",
 				global_poi_cat,
 				bbox.lat1,bbox.lat2,
 				bbox.lon1, bbox.lon2
-				);		
-		
+				);
+
 	}
-	
 
 
-	
+
+
 	if(poi_list)
 	{
 		g_slist_free(poi_list);
 		poi_list = NULL;
 	}
-	sql_execute(db, sql, sql_cb__poi_get);	
-	
-	
+	sql_execute(db, sql, sql_cb__poi_get);
+
+
 	global_show_pois = TRUE;
-	
+
 }
 
 void
@@ -756,7 +723,7 @@ show_poi_detail()
 	float distance=0;
 	waypoint_t *wp = g_new0(waypoint_t, 1);
 	poi_t *p, *this_poi = NULL;
-	
+
 	GladeXML *gladexml = glade_xml_new (gladefile,
 					    "window5",
 					    GETTEXT_PACKAGE);
@@ -764,87 +731,72 @@ show_poi_detail()
 	window = glade_xml_get_widget (gladexml, "window5");
 	g_signal_connect_swapped (window, "destroy",
 				  G_CALLBACK (g_object_unref), gladexml);
-	
-	printf("screen x,y: %d %d \n",mouse_x, mouse_y);
+
 	lat = pixel2lat(global_zoom, global_y+mouse_y);
 	lon = pixel2lon(global_zoom, global_x+mouse_x);
-	
 
-	
+
+
 	lat_deg = rad2deg(lat);
 	lon_deg = rad2deg(lon);
-	printf ("##### Lonitude: %f %f - %f %f \n", lat, lon, lat_deg, lon_deg);
-	
-	
+
 	if(gpsdata !=NULL && !global_myposition.lat && !global_myposition.lon)
 	{
-		distance = 	6371.0 *  
-				acos(sin(deg2rad(gpsdata->fix.latitude)) * 
+		distance = 	6371.0 *
+				acos(sin(deg2rad(gpsdata->fix.latitude)) *
 				sin(lat) +
-		
-				cos(deg2rad(gpsdata->fix.latitude)) * 
-				cos(lat) * 
+
+				cos(deg2rad(gpsdata->fix.latitude)) *
+				cos(lat) *
 				cos(lon - deg2rad(gpsdata->fix.longitude)) );
 	}
 	else if(global_myposition.lat && global_myposition.lon)
 	{
-		distance = 	6371.0 *  
-				acos(sin(deg2rad(global_myposition.lat)) * 
+		distance = 	6371.0 *
+				acos(sin(deg2rad(global_myposition.lat)) *
 				sin(lat) +
-		
-				cos(deg2rad(global_myposition.lat)) * 
-				cos(lat) * 
+
+				cos(deg2rad(global_myposition.lat)) *
+				cos(lat) *
 				cos(lon - deg2rad(global_myposition.lon)) );
-				
+
 	}
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-
-
-	
 	label = lookup_widget(window,"label110");
-	
-	
 
-	
-	
-	
+
+
+
+
+
 	for(list = poi_list; list != NULL; list = list->next)
 	{
 		p = list->data;
-		printf("\n\nPIXEL POI: %d %d   \n\n",p->screen_x,p->screen_y);
-		
+
 		if(abs(p->screen_x - mouse_x) < 12 &&
 		   abs(p->screen_y - mouse_y) < 12 )
-		   
+
 		{
-			
-			printf("FOUND POI X: %d %d %s\n",p->screen_x, mouse_x, 
-				my_strescape_back(p->keywords,NULL));
-	
-			
-			buffer = g_strdup_printf( 
+			buffer = g_strdup_printf(
 				"<b>%s</b> ",
 				my_strescape_back(p->keywords,NULL));
 			buffer2 = g_strdup_printf (_("%s\n\nDistance: %.3fkm"),
 				my_strescape_back(p->desc,NULL), distance);
-printf("%s %s \n",buffer, buffer2);			
 			poi_found = TRUE;
-			
+
 			wp->lat = deg2rad(p->lat_deg);
 			wp->lon = deg2rad(p->lon_deg);
-			
+
 			this_poi = list->data;
 		}
-	
+
 	}
-	
+
 	if(!poi_found)
 		buffer = g_strdup (_("<b>No POI found</b>\n"));
-	
+
 	gtk_label_set_label(GTK_LABEL(label),buffer);
-	
+
 	label = lookup_widget(window,"label111");
 	gtk_label_set_label(GTK_LABEL(label), buffer2);
 
@@ -852,7 +804,7 @@ printf("%s %s \n",buffer, buffer2);
 	g_signal_connect (	(gpointer) widget, "clicked",
 				G_CALLBACK (on_button27_clicked),
 				(gpointer) wp);
-	
+
 	if (this_poi != NULL)
 	{
 		this_poi->widget = window;
@@ -861,66 +813,66 @@ printf("%s %s \n",buffer, buffer2);
 		g_signal_connect (	(gpointer) widget, "clicked",
 					G_CALLBACK (on_button33_clicked),
 					(gpointer) this_poi);
-		
+
 		widget = lookup_widget(window, "button34");
 		g_signal_connect (	(gpointer) widget, "clicked",
 					G_CALLBACK (on_button34_clicked),
 					(gpointer) this_poi);
 	}
-	
+
 	gtk_widget_show(window);
-	
+
 
 }
 
 
 gchar *
 my_strescape_back (const gchar *source,
-	     const gchar *exceptions)
+                   const gchar *exceptions)
 {
-  const guchar *p;
-  gchar *dest;
-  gchar *q;
-  guchar excmap[256];
+	const guchar *p;
+	gchar *dest;
+	gchar *q;
+	guchar excmap[256];
 
-  g_return_val_if_fail (source != NULL, NULL);
+	g_return_val_if_fail (source != NULL, NULL);
 
-  p = (guchar *) source;
-  
-  q = dest = g_malloc (strlen (source) * 4 + 1);
+	p = (guchar *) source;
 
-  memset (excmap, 0, 256);
-  if (exceptions)
-    {
-      guchar *e = (guchar *) exceptions;
+	q = dest = g_malloc (strlen (source) * 4 + 1);
 
-      while (*e)
+	memset (excmap, 0, 256);
+	if (exceptions)
 	{
-	  excmap[*e] = 1;
-	  e++;
+		guchar *e = (guchar *) exceptions;
+
+		while (*e)
+		{
+			excmap[*e] = 1;
+			e++;
+		}
 	}
-    }
 
-  while (*p)
-    {
+	while (*p)
+	{
 
-	  switch (*p)
-	    {
+		switch (*p)
+		{
 
-	    case '&':
-		    *q++ = '&';
-		*q++ = 'a';
-	    	*q++ = 'm';
-	    	*q++ = 'p';
-	    	*q++ = ';';
-	    	break;
-	    default:
-		*q++ = *p;
-	      break;
-	    }
-	
-      p++;
-    }
-  *q = 0;
-  return dest;
+			case '&':
+				*q++ = '&';
+				*q++ = 'a';
+				*q++ = 'm';
+				*q++ = 'p';
+				*q++ = ';';
+				break;
+			default:
+				*q++ = *p;
+				break;
+		}
+
+		p++;
+	}
+	*q = 0;
+	return dest;
 }
