@@ -8,7 +8,7 @@
 #include <glib/gprintf.h>
 #include <string.h>
 #include <curl/curl.h>
-#include <curl/easy.h> 
+#include <curl/easy.h>
 #include <math.h>
 #include "globals.h"
 #include "tile_management.h"
@@ -24,7 +24,7 @@
 #include "tracks.h"
 #include "route.h"
 
-GtkWidget *Bar = NULL; 
+GtkWidget *Bar = NULL;
 static GSList *tile_download_list = NULL;
 
 static gboolean map_redraw_scheduled;
@@ -33,7 +33,7 @@ typedef struct  {
 	char *tile_url;
 } Repo_data_t;
 
-	
+
 
 int
 update_thread_number (int change)
@@ -41,28 +41,28 @@ update_thread_number (int change)
 	static int current_number = 0;
 	int ret_val;
 	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
-	
+
 	g_static_mutex_lock (&mutex);
-	ret_val = current_number += change; 
+	ret_val = current_number += change;
 	g_static_mutex_unlock (&mutex);
 
 
 	return ret_val;
 }
-	
-	
+
+
 gboolean
 map_redraw(void *p)
 {
 	int number_threads;
 	number_threads = update_thread_number(0);
-	
-	
-	
+
+
+
 	if (!drag_started)
 	{
 		map_redraw_scheduled = FALSE;
-	
+
 		fill_tiles_pixel(global_x, global_y, global_zoom, TRUE);
 		paint_track();
 		paint_loaded_track();
@@ -73,39 +73,38 @@ map_redraw(void *p)
 		paint_route();
 		paint_myposition();
 		osd_speed(TRUE);
-		
+
 		return FALSE;
 	}
 	else
 		return TRUE;
-}	
-	
-	
-size_t 
+}
+
+
+size_t
 cb_write_func(void *ptr, size_t size, size_t nmemb, FILE *stream)
 {
-	
-	
-	return 
-	fwrite(ptr, size, nmemb, stream); 
+
+
+	return fwrite(ptr, size, nmemb, stream);
 }
 
 
 size_t
 cb_read_func (void *ptr, size_t size, size_t nmemb, FILE *stream)
 {
-  return fread(ptr, size, nmemb, stream);
+	return fread(ptr, size, nmemb, stream);
 }
 
 int
 cb_progress_func(GtkWidget *Bar,
-                     double t, 
-                     double d, 
+                     double t,
+                     double d,
                      double ultotal,
                      double ulnow)
 {
 
-  return 0;
+	return 0;
 
 }
 
@@ -129,7 +128,7 @@ download_tile(	repo_t *repo,
 	gboolean retval = FALSE;
 	gchar *inp, *outp;
 	int nfmts;
-	
+
 	if(ht==NULL)
 	{
 		ht = g_hash_table_new (g_str_hash, g_str_equal);
@@ -168,27 +167,27 @@ download_tile(	repo_t *repo,
 	if (!repo->inverted_zoom)
 		g_snprintf(tile_url, sizeof tile_url, filtered_repo_uri, zoom, x, y);
 	else
-		g_snprintf(tile_url, sizeof tile_url, filtered_repo_uri, x, y, zoom); 
+		g_snprintf(tile_url, sizeof tile_url, filtered_repo_uri, x, y, zoom);
 	tile_url[(sizeof tile_url) - 1] = '\0';
-	
-	
+
+
 	g_snprintf(tile_data_tmp, sizeof tile_data_tmp, "%s|%s/%d/%d/%d.png|%s/%d/%d/",
 			tile_url,
 			repo->dir, zoom, x, y,
 			repo->dir, zoom, x);
-	
-	
+
+
 	if(strcmp(repo->uri,"maps-for-free")==0)
 	{
 		g_snprintf(tile_data_tmp, sizeof tile_data_tmp,
-				"http://maps-for-free.com/layer/relief/z%d/row%d/%d_%d-%d.jpg"
+				"https://maps-for-free.com/layer/relief/z%d/row%d/%d_%d-%d.jpg"
 				"|%s/%d/%d/%d.png|%s/%d/%d/",
 				zoom,y,zoom,x,y,
 				repo->dir, zoom, x, y,
 				repo->dir, zoom, x);
 		maxzoom=12;
 	}
-	
+
 	if(strcmp(repo->uri,"openaerial")==0)
 	{
 		g_snprintf(tile_data_tmp, sizeof tile_data_tmp,
@@ -202,23 +201,23 @@ download_tile(	repo_t *repo,
 	tile_data_tmp[(sizeof tile_data_tmp) - 1] = '\0';
 
 	tile_data = g_strdup(tile_data_tmp);
-	
+
 	key = g_strdup_printf("%s/%d/%d/%d", repo->dir, zoom, x, y);
 	found = g_hash_table_lookup (ht, key);
 
 	if(!found && zoom <=maxzoom)
 	{
 		g_hash_table_insert(ht, key, &value);
-			
+
 		if (!g_thread_create(&dl_thread, (void *)tile_data, FALSE, NULL) != 0)
 			g_warning("can't create DL thread");
-		
+
 		retval = TRUE;
-	}	
-	
-	
-	
-	
+	}
+
+
+
+
 
 	return retval;
 }
@@ -260,12 +259,12 @@ dl_thread(void *ptr)
 
 
 	mkres = g_mkdir_with_parents(arr1[2],0700);
-	
-	
-	
-	
-	
-	
+
+
+
+
+
+
 	outfile = fopen(arr1[1], "w");
 	if (outfile==NULL)
 	{
@@ -275,7 +274,7 @@ dl_thread(void *ptr)
 
 	curl = curl_easy_init();
 
-	if(curl && outfile) 
+	if(curl && outfile)
 	{
 		/* Multithreading requires setting NOSIGNAL,
 		   otherwise we're likely to crash in the event
@@ -284,26 +283,26 @@ dl_thread(void *ptr)
 		curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
 
 		curl_easy_setopt(curl, CURLOPT_URL, arr1[0]);
-		curl_easy_setopt(curl, CURLOPT_USERAGENT, 
+		curl_easy_setopt(curl, CURLOPT_USERAGENT,
 			"libcurl-agent/1.0 | " PACKAGE " " VERSION " | " __VERSION__);
 		curl_easy_setopt(curl, CURLOPT_WRITEDATA, outfile);
 		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION,	 cb_write_func);
 		curl_easy_setopt(curl, CURLOPT_READFUNCTION,	 cb_read_func);
-		
-		
-		
+
+
+
 		curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, err_buffer);
-		curl_easy_setopt(curl, CURLOPT_FAILONERROR, 1); 
-		
+		curl_easy_setopt(curl, CURLOPT_FAILONERROR, 1);
+
 		res = curl_easy_perform(curl);
-		
+
 		if (res!=0)
 			printf("TILE DL PROBLEM: %s\n   %s\n",err_buffer,tile_data);
-		
-		
+
+
 		curl_easy_cleanup(curl);
-		
-		
+
+
 		gdk_threads_enter();
 		if (!map_redraw_scheduled) {
 			g_timeout_add(500, map_redraw, NULL);
@@ -327,9 +326,9 @@ cb_download_maps(GtkWidget *dialog)
 	GtkToggleButton *z1, *z2, *z3, *z4, *z5, *z6;
 	bbox_t bbox;
 	int zoom_end = 1;
-	
+
 	bbox = get_bbox();
-	
+
 	z1 = (GtkToggleButton *)lookup_widget(dialog, "radiobutton2");
 	z2 = (GtkToggleButton *)lookup_widget(dialog, "radiobutton3");
 	z3 = (GtkToggleButton *)lookup_widget(dialog, "radiobutton4");
@@ -337,14 +336,14 @@ cb_download_maps(GtkWidget *dialog)
 	z5 = (GtkToggleButton *)lookup_widget(dialog, "radiobutton6");
 	z6 = (GtkToggleButton *)lookup_widget(dialog, "radiobutton7");
 
-	zoom_end = (gtk_toggle_button_get_active(z1)) ? global_zoom + 1 : zoom_end; 
+	zoom_end = (gtk_toggle_button_get_active(z1)) ? global_zoom + 1 : zoom_end;
 	zoom_end = (gtk_toggle_button_get_active(z2)) ? global_zoom + 2 : zoom_end;
 	zoom_end = (gtk_toggle_button_get_active(z3)) ? global_zoom + 3 : zoom_end;
 	zoom_end = (gtk_toggle_button_get_active(z4)) ? global_zoom + 4 : zoom_end;
 	zoom_end = (gtk_toggle_button_get_active(z5)) ? global_zoom + 5 : zoom_end;
 	zoom_end = (gtk_toggle_button_get_active(z6)) ? global_zoom + 6 : zoom_end;
-	
-	
+
+
 
 	download_maps(bbox, global_zoom+1, zoom_end);
 
@@ -361,25 +360,20 @@ download_maps(bbox_t bbox, int zoom_start, int zoom_end)
 	bbox_pixel_t bbox_pixel;
 	int zoom;
 
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-
 	zoom_end = (zoom_end > 17) ? 17 : zoom_end;
-	
+
 	for(zoom=zoom_start; zoom<=zoom_end; zoom++)
 	{
 		bbox_pixel = get_bbox_pixel(bbox, zoom);
 		queue_tile_dl_for_bbox(bbox_pixel,zoom);
 	}
-	
-	
+
+
 	g_timeout_add(100, timer_tile_download, NULL);
 
 	for(list = tile_download_list; list != NULL; list = list->next)
-	{		
+	{
 		tile = list->data;
-
-		printf("LIST: %d %d %d %s\n",tile->x, tile->y, tile->zoom,tile->repo->name);	
-		
 	}
 
 }
@@ -388,12 +382,12 @@ tile_t
 get_tile(int pixel_x, int pixel_y, int zoom)
 {
 	tile_t tile;
-	
+
 	tile.x =  (int)floor((float)pixel_x / (float)TILESIZE);
 	tile.y =  (int)floor((float)pixel_y / (float)TILESIZE);
 	tile.zoom = zoom;
 	tile.repo = global_curr_repo->data;
-	
+
 	return tile;
 }
 
@@ -403,28 +397,25 @@ queue_tile_dl_for_bbox(bbox_pixel_t bbox_pixel, int zoom)
 {
 	tile_t tile_11, tile_22;
 	int i,j,k=0;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	tile_11 = get_tile(bbox_pixel.x1, bbox_pixel.y1, zoom);
 	tile_22 = get_tile(bbox_pixel.x2, bbox_pixel.y2, zoom);
-	
-	
+
+
 	for(i=tile_11.x; i<=tile_22.x; i++)
 	{
-		
+
 		for(j=tile_11.y; j<=tile_22.y; j++)
 		{
 			tile_t *tile = g_new0(tile_t,1);
-			printf("### DEBUG queue: %d %d - %d\n",i,j,k);
-			
+
 			k++;
 			tile->x = i;
 			tile->y = j;
 			tile->zoom = zoom;
 			tile->repo = global_curr_repo->data;
-			
-			
+
+
 			tile_download_list = g_slist_prepend(tile_download_list, tile);
 			global_tiles_in_dl_queue++;
 		}
@@ -435,16 +426,12 @@ bbox_t
 get_bbox()
 {
 	bbox_t bbox;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	bbox.lat1 = pixel2lat(global_zoom, global_y);
 	bbox.lon1 = pixel2lon(global_zoom, global_x);
 	bbox.lat2 = pixel2lat(global_zoom, global_y + global_drawingarea_height);
 	bbox.lon2 = pixel2lon(global_zoom, global_x + global_drawingarea_width);
 
-	printf("BBOX: %f %f %f %f \n", bbox.lat1, bbox.lon1, bbox.lat2, bbox.lon2);
-	
 	return bbox;
 }
 
@@ -452,16 +439,12 @@ bbox_t
 get_bbox_deg()
 {
 	bbox_t bbox;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	bbox.lat1 = rad2deg( pixel2lat(global_zoom, global_y) );
 	bbox.lon1 = rad2deg( pixel2lon(global_zoom, global_x) );
 	bbox.lat2 = rad2deg( pixel2lat(global_zoom, global_y + global_drawingarea_height) );
 	bbox.lon2 = rad2deg( pixel2lon(global_zoom, global_x + global_drawingarea_width) );
 
-	printf("BBOX: %f %f %f %f \n", bbox.lat1, bbox.lon1, bbox.lat2, bbox.lon2);
-	
 	return bbox;
 }
 
@@ -469,16 +452,12 @@ bbox_pixel_t
 get_bbox_pixel(bbox_t bbox, int zoom)
 {
 	bbox_pixel_t bbox_pixel;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	bbox_pixel.x1 = lon2pixel(zoom, bbox.lon1);
 	bbox_pixel.y1 = lat2pixel(zoom, bbox.lat1);
 	bbox_pixel.x2 = lon2pixel(zoom, bbox.lon2);
 	bbox_pixel.y2 = lat2pixel(zoom, bbox.lat2);
 
-	printf("DEBUG: xy12 %d %d %d %d \n",bbox_pixel.x1,bbox_pixel.y1,bbox_pixel.x2,bbox_pixel.y2);
-	
 	return	bbox_pixel;
 }
 
@@ -491,24 +470,19 @@ timer_tile_download(gpointer data)
 	gboolean more_tiles = TRUE;
 	int i;
 	int running_downloads, possible_downloads, max_downloads = 6;
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
-	
 	running_downloads = update_thread_number(0);
-	
+
 	possible_downloads = max_downloads - running_downloads;
-	
+
 	for( i=1; i<=possible_downloads; i++)
 	{
-printf("\n\n####LOOP %d %d ###########\n\n",i,possible_downloads);		
 		list = g_slist_nth(tile_download_list, 0);
 		if (list)
 		{
-			
+
 			tile = list->data;
-			printf("\n\n\nTIMER DL: %d %d -- %d\n\n\n", tile->x, tile->y, possible_downloads);
-			
+
 			if(	tile->x >= 0				&&
 				tile->y >= 0				&&
 				tile->x < exp(tile->zoom * M_LN2)	&&
@@ -520,12 +494,11 @@ printf("\n\n####LOOP %d %d ###########\n\n",i,possible_downloads);
 		}
 		else
 		{
-			printf("========= TILE DL LIST END \n");
 			more_tiles = FALSE;
 			global_tiles_in_dl_queue = 0;
 		}
 		tile_download_list = g_slist_delete_link(tile_download_list, list);
 	}
-	
+
 	return more_tiles;
 }
