@@ -41,8 +41,10 @@ bbox_t		get_track_bbox(GSList *track);
 GSList *	load_log_file_into_list(char *file);
 GSList *	load_gpx_file_into_list(char *file);
 GSList * load_ols_XML_file_into_list(char *file);
+GSList * load_kml_XML_file_into_list(char *file);
 GSList * parse_gpx_nodes(xmlNode *node);
 GSList * parse_ols_XML_nodes(xmlNode *node);
+GSList * parse_kml_XML_nodes(xmlNode *node);
 
 void * fetch_track_thread(void *ptr);
 void * fetch_openrouteservice_track_thread(void *ptr);
@@ -51,13 +53,13 @@ void * fetch_openrouteservice_track_thread(void *ptr);
 void
 reset_loaded_track()
 {
-	
+
 	loaded_track = NULL;
 }
 
 void
 paint_track()
-{	
+{
 	GList *list;
 	int pixel_x, pixel_y, x,y, last_x = 0, last_y = 0;
 	int counter = -1, modulo, j=0;
@@ -65,7 +67,7 @@ paint_track()
 	GdkColor color;
 	GdkGC *gc;
 	gboolean is_line = FALSE;
-	
+
 	gc = gdk_gc_new(pixmap);
 	color.green = 0;
 	color.blue = 0;
@@ -80,45 +82,45 @@ paint_track()
 		modulo = 32;
 	else
 		modulo = 1;
-	
+
 	for(list = trackpoint_list->tail; list != NULL; list = list->prev)
 	{
 		counter++;
-		
+
 		if (counter % modulo == 0)
 		{
 			j++;
-			if (j > 300) 
+			if (j > 300)
 			{
-				break; 
+				break;
 			}
-			
+
 			trackpoint_t *tp = list->data;
-		
+
 			lat = tp->lat;
 			lon = tp->lon;
-			
-			
-			
+
+
+
 			pixel_x = lon2pixel(global_zoom, lon);
 			pixel_y = lat2pixel(global_zoom, lat);
-			
+
 			x = pixel_x - global_x;
 			y = pixel_y - global_y;
-			
-	
+
+
 			if(is_line)
 			{
 				gdk_draw_line (pixmap, gc, x, y, last_x, last_y);
 				gtk_widget_queue_draw_area (
-					map_drawable, 
+					map_drawable,
 					x-4, y-4,
 					8,8);
 			}
-			
+
 			last_x = x;
 			last_y = y;
-			
+
 			is_line = TRUE;
 		}
 	}
@@ -128,14 +130,14 @@ paint_track()
 void
 paint_loaded_track()
 {
-	
+
 	GSList *list;
 	int pixel_x, pixel_y, x,y, last_x = 0, last_y = 0;
 	float lat, lon;
 	GdkColor color;
 	GdkGC *gc;
 	gboolean is_line = FALSE;
-	
+
 	gc = gdk_gc_new(pixmap);
 	color.green = 50000;
 	color.blue = 0;
@@ -144,38 +146,38 @@ paint_loaded_track()
 	gdk_gc_set_line_attributes(gc,
 		5, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND);
 
-	
+
 	for(list = loaded_track; list != NULL; list = list->next)
 	{
 		trackpoint_t *tp = list->data;
-	
+
 		lat = tp->lat;
 		lon = tp->lon;
-		
-		
-		
-		
+
+
+
+
 		pixel_x = lon2pixel(global_zoom, lon);
 		pixel_y = lat2pixel(global_zoom, lat);
-		
+
 		x = pixel_x - global_x;
 		y = pixel_y - global_y;
-		
+
 
 		if(is_line)
 		{
 			gdk_draw_line (pixmap, gc, x, y, last_x, last_y);
 			gtk_widget_queue_draw_area (
-				map_drawable, 
+				map_drawable,
 				x-4, y-4,
 				8,8);
-			
+
 		}
-		
+
 		last_x = x;
 		last_y = y;
-		
-		
+
+
 		is_line = TRUE;
 	}
 }
@@ -193,15 +195,15 @@ track_log()
 	time_t time_sec;
 	struct tm *ts;
 	int heartfreq = 42;
-	
-	
+
+
 	if(gpsdata->valid)
 	{
-		
+
 		time_sec = (time_t)gpsdata->fix.time;
 		ts = gmtime(&time_sec);
 		strftime(buffer, sizeof(buffer), "%Y-%m-%dT%H:%M:%SZ", ts);
-		
+
 		heartfreq = (hrmdata) ? hrmdata->freq : 0;
 
 		switch (gpsdata->fix.mode) {
@@ -253,8 +255,8 @@ track_log()
 			         "</trkpt>\n",
 			         gpsdata->fix.speed,
 			         gpsdata->fix.heading);
-      }
-  }
+		}
+	}
 }
 
 void
@@ -266,23 +268,21 @@ track_log_open()
 	gchar *filename = NULL;
 	GtkLabel *label76;
 	gchar *labeltext;
-	
+
 	label76 = GTK_LABEL(lookup_widget(window1, "label76"));
-	
-	
+
+
 	time_epoch_sec = time(NULL);
 	tm_struct = localtime(&time_epoch_sec);
-	
-	
-	
+
+
+
 
 	strftime (buffer, sizeof (buffer), "%Y%m%d_%H%M%S%z.gpx", tm_struct);
 
-	
+
 	filename = g_strconcat(global_track_dir, buffer,NULL);
-	
-	printf("*** %s(): %s\n",__PRETTY_FUNCTION__,filename);
-	
+
 	if(fp==NULL && trip_logger_on)
 	{
 		fp = fopen(filename,"w");
@@ -295,11 +295,11 @@ track_log_open()
 			                       "Error opening logfile"
 			                       "</span>"));
 		}
-		else 
+		else
 		{
 			labeltext = g_strdup_printf (_("<b><span foreground='#0000ff'>Log: %s</span></b>"), buffer);
 			gtk_label_set_label(label76,labeltext);
-			g_free(labeltext);	
+			g_free(labeltext);
 
 			fprintf(fp, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 			            "<gpx version=\"1.1\"\n"
@@ -315,7 +315,7 @@ track_log_open()
 			            "<trkseg>\n");
 		}
 	}
-	
+
 	g_free(filename);
 }
 
@@ -327,12 +327,8 @@ track_log_close()
 	GtkLabel *label76;
 	label76 = GTK_LABEL(lookup_widget(window1, "label76"));
 	gtk_label_set_label(label76,"");
-	
-	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-	
-	if(fp) {
-		printf("closing FP\n");
 
+	if(fp) {
 		fprintf (fp, "\n"
 		         "</trkseg>\n"
 		         "</trk>\n"
@@ -340,7 +336,7 @@ track_log_close()
 
 		ret = fclose(fp);
 		fp = NULL;
-	
+
 		if(ret) printf("ERROR closing file\n");
 	}
 }
@@ -358,10 +354,10 @@ tracks_open_tracks_dialog()
 	GList *list = NULL;
 
 	GtkWidget *label, *vbox, *eventbox;
-	
+
 
 	dir = g_dir_open(global_track_dir, 0, &err);
-	
+
 	if (err != NULL)
 	{
 		fprintf (stderr, _("Problem opening directory: %s\n"),
@@ -369,22 +365,22 @@ tracks_open_tracks_dialog()
 		g_error_free (err);
 		return;
 	}
-	
-	
-	
+
+
+
 	window12 = glade_xml_get_widget(gladexml, "window12");
 	gtk_widget_show(window12);
-	
-	vbox = lookup_widget(window12, "vbox39");		
-	
-	
-	
+
+	vbox = lookup_widget(window12, "vbox39");
+
+
+
 	file = g_dir_read_name(dir);
 
 	while (file)
 	{
 		isfile = g_file_test(g_strconcat(global_track_dir,file,NULL), G_FILE_TEST_IS_REGULAR);
-		
+
 		if(isfile)
 			list = g_list_insert_sorted( list, g_strdup(file), (GCompareFunc) g_strcmp0 );
 
@@ -394,28 +390,26 @@ tracks_open_tracks_dialog()
 	for(; list!=NULL; list=list->next)
 	{
 		char *file = list->data;
-		
-		
-		printf("%s \n", file);
+
 		eventbox = gtk_event_box_new ();
 		gtk_widget_set_events (eventbox, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_ENTER_NOTIFY_MASK);
 		gtk_widget_show (eventbox);
-		
+
 
 		gtk_box_pack_start (GTK_BOX (vbox), eventbox, FALSE, FALSE, 0);
-		
+
 		label = make_file_label(file, g_strconcat(global_track_dir,file,NULL));
 		gtk_widget_show(label);
 		gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 		gtk_misc_set_padding (GTK_MISC (label), 3, 2);
 
 		gtk_container_add (GTK_CONTAINER (eventbox), label);
-		
+
 		g_signal_connect ((gpointer) eventbox, "button_release_event",
 				G_CALLBACK (tracks_on_file_button_release_event),
 				g_strconcat(global_track_dir,file,NULL));
 	}
-	
+
 	g_list_free(list);
 	g_dir_close(dir);
 }
@@ -425,14 +419,14 @@ GtkWidget *
 make_file_label(const char *file, char *full_file)
 {
 	GtkWidget *label;
-	
+
 	label = gtk_label_new (g_strdup(file));
-	
+
 	return label;
 }
 
 void
-show_bbox (bbox_t bbox) 
+show_bbox (bbox_t bbox)
 {
 	GtkWidget *drawingarea, *range;
 	int track_zoom, width, height;
@@ -462,10 +456,10 @@ tracks_on_file_button_release_event   (	GtkWidget       *widget,
 	GtkWidget *widget_tmp;
 	char *file;
 	bbox_t bbox;
-	
+
 	widget_tmp = lookup_widget(window1, "button79");
 	gtk_widget_show(widget_tmp);
-	
+
 	file = (char *) user_data;
 
 	if (widget && window12) {
@@ -485,7 +479,7 @@ tracks_on_file_button_release_event   (	GtkWidget       *widget,
 
 		gtk_widget_hide(window12);
 
-		vbox = lookup_widget(window12, "vbox39");		
+		vbox = lookup_widget(window12, "vbox39");
 		gtk_container_foreach (GTK_CONTAINER (vbox),
 				       (GtkCallback) gtk_widget_destroy,
 				       NULL);
@@ -515,7 +509,7 @@ tracks_on_file_button_release_event   (	GtkWidget       *widget,
 
 	paint_loaded_track();
 
-	return FALSE;	
+	return FALSE;
 }
 
 
@@ -526,17 +520,17 @@ get_track_bbox(GSList *track)
 	GSList *list;
 	bbox_t bbox;
 	double lat, lon;
-	
+
 	bbox.lat1 =  -90;
 	bbox.lon1 =  180;
 	bbox.lat2 =   90;
 	bbox.lon2 = -180;
-	
-	
+
+
 	for(list = track; list != NULL; list = list->next)
 	{
 		trackpoint_t *tp = list->data;
-	
+
 		lat = tp->lat;
 		lon = tp->lon;
 		bbox.lat1 = (lat > bbox.lat1) ? lat : bbox.lat1;
@@ -544,7 +538,7 @@ get_track_bbox(GSList *track)
 		bbox.lon1 = (lon < bbox.lon1) ? lon : bbox.lon1;
 		bbox.lon2 = (lon > bbox.lon2) ? lon : bbox.lon2;
 	}
-	
+
 	return bbox;
 }
 
@@ -567,17 +561,17 @@ load_log_file_into_list(char *file)
 		trackpoint_t *tp;
 		char *latstr, *lonstr;
 		char *parseptr;
-		
+
 		latstr = strtok_r (line, ",", &parseptr);
 		lonstr = strtok_r (NULL, ",", &parseptr);
-		
-		
+
+
 		if (latstr == NULL || lonstr == NULL) continue;
 
 
 		tp = g_new0 (trackpoint_t, 1);
 		tp->lat = deg2rad (atof (latstr));
-		tp->lon = deg2rad (atof (lonstr));		
+		tp->lon = deg2rad (atof (lonstr));
 
 		list = g_slist_append(list, tp);
 	}
@@ -594,12 +588,12 @@ load_gpx_file_into_list(char *file)
 	GSList *list = NULL;
 	xmlDoc *doc = NULL;
 	xmlNode *root_element = NULL;
-	
-	
+
+
 	LIBXML_TEST_VERSION
-	
+
 	doc = xmlReadFile(file, NULL, 0);
-	
+
 	if (doc == NULL) {
 		printf("error: could not parse file %s\n", file);
 	} else {
@@ -618,13 +612,13 @@ load_gpx_string_into_list(char *gpx_string)
 	GSList *list = NULL;
 	xmlDoc *doc = NULL;
 	xmlNode *root_element = NULL;
-	
+
 	if(!gpx_string) return NULL;
-	
+
 	LIBXML_TEST_VERSION
-	
+
 	doc = xmlReadMemory(gpx_string, strlen(gpx_string), "noname.xml", NULL, 0);
-	
+
 	if (doc == NULL) {
 		fprintf (stderr, _("Failed to parse document\n"));
 	} else {
@@ -643,13 +637,13 @@ load_ols_XML_string_into_list(char *ols_string)
 	GSList *list = NULL;
 	xmlDoc *doc = NULL;
 	xmlNode *root_element = NULL;
-	
+
 	if(!ols_string) return NULL;
-	
+
 	LIBXML_TEST_VERSION
-	
+
 	doc = xmlReadMemory(ols_string, strlen(ols_string), "noname.xml", NULL, 0);
-	
+
 	if (doc == NULL) {
 		fprintf (stderr, _("Failed to parse document\n"));
 	} else {
@@ -661,6 +655,30 @@ load_ols_XML_string_into_list(char *ols_string)
 	return list;
 }
 
+GSList *
+load_kml_XML_string_into_list(char *kml_string)
+{
+	GSList *list = NULL;
+	xmlDoc *doc = NULL;
+	xmlNode *root_element = NULL;
+
+	if(!kml_string) return NULL;
+
+	LIBXML_TEST_VERSION
+
+	doc = xmlReadMemory(kml_string, strlen(kml_string), "noname.xml", NULL, 0);
+
+	if (doc == NULL) {
+		fprintf (stderr, _("Failed to parse document\n"));
+	} else {
+		root_element = xmlDocGetRootElement(doc);
+		list = parse_kml_XML_nodes(root_element);
+		xmlFreeDoc(doc);
+	}
+
+	return list;
+}
+
 GSList *
 parse_gpx_nodes(xmlNode *node)
 {
@@ -677,7 +695,7 @@ parse_gpx_nodes(xmlNode *node)
 			{
 				double lat, lon;
 				trackpoint_t *tp = g_new0(trackpoint_t,1);
-				
+
 				if (xmlHasProp(cur_node, BAD_CAST "junction") &&
 				    strcmp(xmlGetProp(cur_node, BAD_CAST "junction"), "") == 0)
 				{
@@ -686,20 +704,16 @@ parse_gpx_nodes(xmlNode *node)
 
 				lat = atof((char *)xmlGetProp(cur_node, BAD_CAST "lat"));
 				lon = atof((char *)xmlGetProp(cur_node, BAD_CAST "lon"));
-				
+
 				tp->lat = deg2rad(lat);
 				tp->lon = deg2rad(lon);
 
 				list = g_slist_append(list, tp);
 			}
-			else
-			{
-				printf("  OTHER XML ELEMENT: %s \n", cur_node->name);
-			}
 		}
 		list = g_slist_concat(list, parse_gpx_nodes(cur_node->children));
 	}
-	
+
 	return list;
 }
 
@@ -750,7 +764,61 @@ parse_ols_XML_nodes(xmlNode *node)
 		}
 		list = g_slist_concat(list, parse_ols_XML_nodes(cur_node->children));
 	}
-	
+
+	return list;
+}
+
+GSList *
+parse_kml_XML_nodes(xmlNode *node)
+{
+	xmlNode *cur_node = NULL;
+	GSList *list = NULL;
+
+	for (cur_node = node; cur_node; cur_node = cur_node->next)
+	{
+		if (xmlStrEqual(cur_node->name, BAD_CAST "Placemark"))
+		{
+			xmlNode *geometry_node = cur_node->children;
+			while (geometry_node != NULL)
+			{
+				if (xmlStrEqual(geometry_node->name, BAD_CAST "LineString"))
+				{
+					xmlNode *inner_cur_node = geometry_node->children;
+					while (inner_cur_node != NULL)
+					{
+						if (xmlStrEqual(inner_cur_node->name, BAD_CAST "coordinates")) {
+							char** lonlatlist;
+							lonlatlist = g_strsplit(xmlNodeGetContent(inner_cur_node), "\n", -1);
+							for(unsigned int i = 0; lonlatlist[i]; i++){
+								g_strchug(lonlatlist[i]);
+								g_strchomp(lonlatlist[i]);
+								char** lonlat = g_strsplit(lonlatlist[i], ",", 2);
+								if (lonlat[0])
+								{
+									double lat, lon;
+									lon = atof(lonlat[0]);
+									if (lonlat[1])
+									{
+										trackpoint_t *tp = g_new0(trackpoint_t,1);
+										lat = atof(lonlat[1]);
+										tp->lat = deg2rad(lat);
+										tp->lon = deg2rad(lon);
+										list = g_slist_append(list, tp);
+									}
+								}
+								g_strfreev (lonlat);
+							}
+							g_strfreev (lonlatlist);
+						}
+						inner_cur_node = inner_cur_node->next;
+					}
+				}
+				geometry_node = geometry_node->next;
+			}
+		}
+		list = g_slist_concat(list, parse_kml_XML_nodes(cur_node->children));
+	}
+
 	return list;
 }
 
@@ -776,7 +844,7 @@ fetch_track(GtkWidget *widget, char *service, char *start, char *end)
 
 		tmpWidget = lookup_widget(dialog10, "okbutton11");
 		gtk_widget_set_sensitive(tmpWidget, TRUE);
-		
+
 		g_warning("###unknown route service (%s) selected\n", service);
 	}
 }
@@ -794,9 +862,8 @@ void fetch_yournavigation_track(GtkWidget *widget, char *start, char *end)
 	endlatstr = strtok_r (end, ",", &parseptr);
 	endlonstr = strtok_r (NULL, ",", &parseptr);
 	dialog10 = widget;
-	printf("%s(): %s, %s\n",__PRETTY_FUNCTION__, start, end);
-	
-	url = g_strdup_printf("http://www.yournavigation.org/api/dev/gosmore.php?format=gpx&flat=%s&flon=%s&tlat=%s&tlon=%s&v=motorcar&fast=1&layer=mapnik",startlatstr, startlonstr, endlatstr, endlonstr);
+
+	url = g_strdup_printf("http://www.yournavigation.org/api/1.0/gosmore.php?format=kml&flat=%s&flon=%s&tlat=%s&tlon=%s&v=motorcar&fast=1&layer=mapnik",startlatstr, startlonstr, endlatstr, endlonstr);
 	if (!g_thread_create(&fetch_track_thread, (void *)url, FALSE, NULL) != 0)
 		g_warning("### can't create route thread\n");
 }
@@ -805,7 +872,6 @@ void fetch_openrouteservice_track(GtkWidget *widget, char *start, char *end)
 {
 	char *url;
 	dialog10 = widget;
-	printf("%s(): %s, %s\n",__PRETTY_FUNCTION__, start, end);
 	char *startlatstr;
 	char *startlonstr;
 	char *endlatstr;
@@ -816,7 +882,7 @@ void fetch_openrouteservice_track(GtkWidget *widget, char *start, char *end)
 	endlatstr = strtok_r (end, ",", &parseptr);
 	endlonstr = strtok_r (NULL, ",", &parseptr);
 	char *request;
-	
+
 	request = g_strdup_printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 	                          "<xls:XLS xmlns:xls=\"http://www.opengis.net/xls\" xmlns:sch=\"http://www.ascc.net/xml/schematron\" "
 	                          "xmlns:gml=\"http://www.opengis.net/gml\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" "
@@ -825,7 +891,7 @@ void fetch_openrouteservice_track(GtkWidget *widget, char *start, char *end)
 	                          "http://schemas.opengis.net/ols/1.1.0/RouteService.xsd\" version=\"1.1\" xls:lang=\"en\">\n"
 	                          "<xls:RequestHeader/>\n"
 	                          "<xls:Request methodName=\"RouteRequest\" requestID=\"999\" version=\"1.1\">\n"
-	                          "<xls:DetermineRouteRequest distanceUnit=\"KM\">\n"    
+	                          "<xls:DetermineRouteRequest distanceUnit=\"KM\">\n"
 	                          "<xls:RoutePlan>\n"
 	                          "<xls:RoutePreference>Fastest</xls:RoutePreference>"
 	                          "<xls:WayPointList>\n"
@@ -869,7 +935,7 @@ void fetch_openrouteservice_track(GtkWidget *widget, char *start, char *end)
 void process_fetched_track(postreply_t *reply, bool save_gpx)
 {
 	bbox_t bbox;
-	
+
 	if(loaded_track)
 	{
 		if (save_gpx)
@@ -878,14 +944,14 @@ void process_fetched_track(postreply_t *reply, bool save_gpx)
 			time_t time_epoch_sec;
 			struct tm  *tm_struct;
 			gchar buffer[256];
-			gchar *filename = NULL;	
-		
+			gchar *filename = NULL;
+
 			time_epoch_sec = time(NULL);
 			tm_struct = localtime(&time_epoch_sec);
 			strftime(buffer, sizeof(buffer), "nav%Y%m%d_%H%M%S%z.gpx", tm_struct);
-		
+
 			filename = g_strconcat(global_track_dir, buffer,NULL);
-	
+
 			fp = fopen(filename,"w");
 			if(!fp)
 			{
@@ -897,10 +963,10 @@ void process_fetched_track(postreply_t *reply, bool save_gpx)
 				fprintf(fp,"%s", reply->data);
 				fclose(fp);
 			}
-			
+
 			g_free(filename);
 		}
-		
+
 		gdk_threads_enter();
 		{
 			if(loaded_track)
@@ -917,47 +983,47 @@ void process_fetched_track(postreply_t *reply, bool save_gpx)
 	else
 	{
 		const char *err_msg;
-		
-		
-		
+
+
+
 		if(reply->status_code == 200)
 			err_msg = g_strdup (_("<span color='#aa0000'><b>"
 			                      "Oops! No Route found"
 			                      "</b></span>\n"
 			                      "Try with another Start/End"));
-		
-		
+
+
 		else if(reply->status_code == 203)
 			err_msg = g_strdup(reply->data);
-		
-		
+
+
 		else if (reply->status_code)
 			err_msg = g_strdup (_("<span color='#aa0000'><b>"
 			                      "Duh! A Server Error"
 			                      "</b></span>\n"
 			                      "Maybe try later again..."));
-		
-		
+
+
 		else
 			err_msg = g_strdup (_("<span color='#aa0000'><b>"
 			                      "Oh! A Network Error"
 			                      "</b></span>\n"
 			                      "Check the internet!"));
-		
+
 		gdk_threads_enter();
 		{
 			GtkWidget *widget;
 
 			widget = lookup_widget(dialog10, "label190");
 			gtk_label_set_label(GTK_LABEL(widget), err_msg);
-			
+
 			widget = lookup_widget(dialog10, "okbutton11");
-			gtk_widget_set_sensitive(widget, TRUE);			
+			gtk_widget_set_sensitive(widget, TRUE);
 		}
 		gdk_threads_leave();
-	
+
 	}
-		
+
 }
 
 void *
@@ -966,17 +1032,16 @@ fetch_openrouteservice_track_thread(void *ptr)
 	postreply_t *reply = NULL;
 	char *url;
 	char *request;
-	
+
 	url = ((char**)ptr)[0];
 	request = ((char**)ptr)[1];
-	
-	
+
+
 	reply = mycurl__do_http_post_XML(url, request, NULL);
 
-	printf("HTTP-POST: size: %d, statuscode %d \n", (int)reply->size, (int)reply->status_code);
 	loaded_track = load_ols_XML_string_into_list(reply->data);
 	process_fetched_track(reply, false);
-	
+
 	g_free(url);
 	g_free(request);
 	g_free((char**)ptr);
@@ -991,19 +1056,17 @@ fetch_track_thread(void *ptr)
 	GtkWidget *range, *drawingarea;
 	int track_zoom, width, height;
 	bbox_t bbox;
-	
+
 	drawingarea = lookup_widget(window1, "drawingarea1");
 	width  = drawingarea->allocation.width;
 	height = drawingarea->allocation.height;
-	
+
 	url = ptr;
-	
-	reply = mycurl__do_http_get(url, NULL); 
 
-	printf("HTTP-GET: size: %d, statuscode %d \n", (int)reply->size, (int)reply->status_code);
+	reply = mycurl__do_http_get(url, NULL);
 
-	loaded_track = load_gpx_string_into_list(reply->data);
+	loaded_track = load_kml_XML_string_into_list(reply->data);
 	process_fetched_track(reply, true);
-		
+
 	return NULL;
 }
